beta_interval.RdComputes Probability Interval for a Beta Curve
beta_interval(prob, shape_par)
| prob | value of coverage probability |
|---|---|
| shape_par | vector of shape parameters of the beta curve |
Computes and displays the "equal tails" interval that contains the beta curve with the specified probability
parameters <- c(2, 5) beta_interval(.5, parameters)