beta_quantile.RdDisplays a Quantile of a Beta Curve
beta_quantile(prob, shape_par)
| prob | probability value of interest |
|---|---|
| shape_par | vector of shape parameters of the beta curve |
Displays the quantile of a beta curve corresponding to the probability value
# find the .50 quantile (the median) prob <- 0.5 parameters <- c(2, 5) beta_quantile(prob, parameters)# find the .90 quantile (90th percentile) prob <- 0.9 beta_quantile(prob, parameters)