Learn R Programming

TeachBayes (version 0.1.0)

draw_two_p: Plot of Distribution of Two Proportions

Description

Constructs a graph of the probability distribution of two proportions

Usage

draw_two_p(prob_matrix, ...)

Arguments

prob_matrix
matrix of probabilities with labels the values of the proportions
...
other arguments such as the title of the plot

Value

graphical display of the joint probability distribution

Examples

Run this code
  Prob <- testing_prior()
  draw_two_p(Prob, title="Testing Prior")

Run the code above in your browser using DataLab