Learn R Programming

TeachBayes (version 0.1.0)

many_normal_plots: Graph of several normal curves

Description

Graph of several normal curves

Usage

many_normal_plots(list_normal_par)

Arguments

list_normal_par
list of vectors, where each vector is a mean and standard deviation for a normal distribution

Value

Displays the normal curves on a single panel with labels

Examples

Run this code
 many_normal_plots(list(c(100, 15), c(110, 15)))

Run the code above in your browser using DataLab